Authors
-------

Ziad Sawalha <ziad@sawalha.com)

Based on `mongobox` by Roman Kalyakin, which is
based on `mongonose` plugin by Kapil Thangavelu.

Contributors
------------
 * Ziad Sawalha (http://github.com/ziadsawalha)
